#

##

##

##

##

    	umuntu
    		# umuntu (Zulu)
    		# tangata (Maori)
    		# mtu (Swahili)
    		# osoba (Polish)
    		# người (Vietnamese)
    		# 人
    		# homo sapien
    		# person
    		# human

    	summary

    	relevant
    		FDA recommended daily values:

    	NIH
    		https://ods.od.nih.gov/HealthInformation/nutrientrecommendations.aspx

    	Dietary Reference Intakes
    		https://en.wikipedia.org/wiki/Dietary_Reference_Intake#/media/File:Dietary_Reference_Intakes.svg